==> mu-0.1.16.jar: project.clj <==
(defproject farbetter/mu "0.1.16"
  :description "A microservices framework for Clojure and Clojurescript"
  :url "https://github.com/farbetter/mu"
  :license {:name "The Apache Software License, Version 2.0"
            :url "http://www.apache.org/licenses/LICENSE-2.0.txt"}
  :lein-release {:scm :git
                 :deploy-via :clojars}

  :profiles
  {:dev
   {:plugins
    [;; Because of confusion with a defunct project also called
     ;; lein-release, we exclude lein-release from lein-ancient.
     [lein-release "1.0.9" :upgrade false :exclusions [org.clojure/clojure]]
     [lein-cljsbuild "1.1.4"]]}}

  :dependencies
  [[com.taoensso/timbre "4.7.4" :exclusions [org.clojure/tools.reader]]
   [farbetter/pete "0.1.10"]
   [farbetter/roe "0.1.18"]
   [farbetter/utils "0.1.58"]
   [farbetter/freedomdb "0.2.5"]
   [org.clojure/clojure "1.8.0"]
   [org.clojure/clojurescript "1.9.229"]
   [org.clojure/core.async "0.2.391" :exclusions [org.clojure/tools.reader]]
   [prismatic/schema "1.1.3"]
   [stylefruits/gniazdo "1.0.0"]]

  ;; :global-vars {*warn-on-reflection* true}

  :cljsbuild
  {:builds
   [{:id "node-test-none"
     :source-paths ["src" "test"]
     :notify-command ["node" "target/test/node_test_none/test_main.js"]
     :compiler
     {:optimizations :none
      :main "farbetter.test-runner"
      :target :nodejs
      :output-to "target/test/node_test_none/test_main.js"
      :output-dir "target/test/node_test_none"
      :source-map true}}
    {:id "node-test-adv"
     :source-paths ["src" "test"]
     :notify-command ["node" "target/test/node_test_adv/test_main.js"]
     :compiler
     {:optimizations :advanced
      :main "farbetter.test-runner"
      :target :nodejs
      :static-fns true
      :output-to  "target/test/node_test_adv/test_main.js"
      :output-dir "target/test/node_test_adv"
      :source-map "target/test/node_test_adv/map.js.map"}}]}

  :test-selectors {:default (complement :integration)
                   :integration :integration
                   :the-one :the-one
                   :all (constantly true)}

  :aliases
  {"auto-test-cljs" ["do"
                     "clean,"
                     "cljsbuild" "auto" "node-test-none"]
   "auto-test-cljs-adv" ["do"
                         "clean,"
                         "cljsbuild" "auto" "node-test-adv"]})

==> mu-0.1.23.jar: project.clj <==
(defproject farbetter/mu "0.1.23"
  :description "A microservices framework for Clojure and Clojurescript"
  :url "https://github.com/farbetter/mu"
  :license {:name "The Apache Software License, Version 2.0"
            :url "http://www.apache.org/licenses/LICENSE-2.0.txt"}
  :lein-release {:scm :git
                 :deploy-via :clojars}
  :pedantic? :abort

  :profiles
  {:dev
   {:global-vars {*warn-on-reflection* true}
    :plugins
    [[lein-ancient "0.6.10"]
     ;; Because of confusion with a defunct project also called
     ;; lein-release, we exclude lein-release from lein-ancient.
     [lein-release "1.0.9" :upgrade false :exclusions [org.clojure/clojure]]
     [lein-cljsbuild "1.1.7"]]}}

  :dependencies
  [[com.taoensso/timbre "4.10.0" :exclusions [org.clojure/tools.reader]]
   [farbetter/pete "0.1.13"]
   [farbetter/roe "0.1.23"]
   [farbetter/utils "0.1.64"]
   [farbetter/freedomdb "0.2.11"]
   [org.clojure/clojure "1.8.0"]
   [org.clojure/clojurescript "1.9.908"]
   [org.clojure/core.async "0.3.443"]
   [prismatic/schema "1.1.6"]
   [stylefruits/gniazdo "1.0.1"]]

  :cljsbuild
  {:builds
   [{:id "node-test-none"
     :source-paths ["src" "test"]
     :notify-command ["node" "target/test/node_test_none/test_main.js"]
     :compiler
     {:optimizations :none
      :main "farbetter.test-runner"
      :target :nodejs
      :output-to "target/test/node_test_none/test_main.js"
      :output-dir "target/test/node_test_none"
      :source-map true
      :parallel-build true}}
    {:id "node-test-adv"
     :source-paths ["src" "test"]
     :notify-command ["node" "target/test/node_test_adv/test_main.js"]
     :compiler
     {:optimizations :advanced
      :main "farbetter.test-runner"
      :target :nodejs
      :static-fns true
      :output-to  "target/test/node_test_adv/test_main.js"
      :output-dir "target/test/node_test_adv"
      :source-map "target/test/node_test_adv/map.js.map"
      :parallel-build true}}]}

  :test-selectors {:default (complement :integration)
                   :integration :integration
                   :the-one :the-one
                   :all (constantly true)}

  :aliases
  {"auto-test-cljs" ["do"
                     "clean,"
                     "cljsbuild" "auto" "node-test-none"]
   "auto-test-cljs-adv" ["do"
                         "clean,"
                         "cljsbuild" "auto" "node-test-adv"]})
